==> dsgui-1.0-rc1.tar.gz: dsgui-1.0-rc1/setup.py <==
#! /usr/bin/python
# encoding: utf-8

#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA


import sys
import glob
import os
from setuptools import setup

# available languages to pack
langs = [l for l in os.listdir('locale')
         if os.path.isdir('locale/'+l) and
            os.path.exists( 'locale/'+l+'/LC_MESSAGES/dsgui.mo')]

#print "found languages:", langs
localizations = [('share/locale/'+lang+'/LC_MESSAGES',
                  ['locale/'+lang+'/LC_MESSAGES/dsgui.mo']) for lang in langs]
icons = []
for d in os.listdir('icons'):
  dname = os.path.join('icons',d)
  if os.path.isdir(dname):
    icon_name = os.path.join(dname, 'dsgui.png')
    if os.path.isfile(icon_name):
      dest_dir = os.path.join('/usr/share/icons/hicolor/',d,'apps')
      icons.append((dest_dir,[icon_name]))
print icons

data_files = [('share/dsgui/doc', ['doc/index.html']),
              ('share/dsgui/icons',glob.glob('icons/*.png')+glob.glob('icons/*.svg')),
              ('share/dsgui/ui',glob.glob('ui/*.ui')),
              ] + localizations
              
if sys.platform != "darwin":
  data_files += [("/usr/share/icons/hicolor/scalable/apps", ["icons/dsgui.svg"]),
                 ("/usr/share/applications", ["dsgui.desktop"]),
                 ] + icons
# the setup itself
data = dict(
  name = 'dsgui',
  version = '1.0-rc1',
  description = "dsgui is a free graphical interface for 'Datove schranky'",
  author = "CZ.NIC Labs",
  author_email = "datove-schranky@labs.nic.cz",
  url = "http://labs.nic.cz/datove-schranky/",
  license = "GNU LGPL",
  platforms = ["Unix", "Windows","MacOS X"],
  long_description = open("README.txt").read(), #.decode('utf-8'),
  
  packages=['dsgui'],
  package_dir = {'dsgui': './'},
  data_files = data_files,
  scripts = ['dsgui'],
  requires=['gtk',"pygtk",'dslib',"SQLAlchemy (>=0.5)"],
  install_requires=['dslib>=1.0-rc1',"SQLAlchemy>=0.5"],
  zip_safe=False,
  )

if sys.platform == "darwin":
  data.update(
    options={'py2app': {'argv_emulation': True}},
    app=['dsgui.py'],
    setup_requires=['py2app'],
    install_requires=["SQLAlchemy>=0.5"],
    )

set = setup(**data)

==> dsgui-1.1.2.tar.gz: dsgui-1.1.2/setup.py <==
#! /usr/bin/python
# encoding: utf-8

#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA


import sys
import glob
import os
from setuptools import setup
import release

# available languages to pack
langs = [l for l in os.listdir('locale')
         if os.path.isdir('locale/'+l) and
            os.path.exists( 'locale/'+l+'/LC_MESSAGES/dsgui.mo')]

#print "found languages:", langs
localizations = [('share/locale/'+lang+'/LC_MESSAGES',
                  ['locale/'+lang+'/LC_MESSAGES/dsgui.mo']) for lang in langs]
icons = []
for d in os.listdir('icons'):
  dname = os.path.join('icons',d)
  if os.path.isdir(dname):
    icon_name = os.path.join(dname, 'dsgui.png')
    if os.path.isfile(icon_name):
      dest_dir = os.path.join('/usr/share/icons/hicolor/',d,'apps')
      icons.append((dest_dir,[icon_name]))
#print icons

data_files = [('share/dsgui/doc', ['doc/index.html','doc/style.css']+
               glob.glob('doc/*.png')),
              ('share/dsgui/icons',glob.glob('icons/*.png')+glob.glob('icons/*.svg')),
              ('share/dsgui/fonts',glob.glob('fonts/*')),
              ('share/dsgui/ui',glob.glob('ui/*.ui')),
              ] + localizations
              
if sys.platform != "darwin":
  data_files += [("/usr/share/icons/hicolor/scalable/apps", ["icons/dsgui.svg"]),
                 ("/usr/share/applications", ["dsgui.desktop"]),
                 ] + icons
# the setup itself
data = dict(
  name = 'dsgui',
  version = release.DSGUI_VERSION,
  description = "dsgui is a free graphical interface for 'Datove schranky'",
  author = "CZ.NIC Labs",
  author_email = "datove-schranky@labs.nic.cz",
  url = "http://labs.nic.cz/datove-schranky/",
  license = "GNU LGPL",
  platforms = ["Unix", "Windows","MacOS X"],
  long_description = "dsgui is a GUI application allowing access to \
a 'Databox' - an electronic communication interface endorsed by the Czech \
government.",
  
  packages=['dsgui'],
  package_dir = {'dsgui': './'},
  data_files = data_files,
  scripts = ['dsgui'],
  requires=['gtk',"pygtk",'dslib (>=1.1)',"SQLAlchemy (>=0.5)"],
  install_requires=['dslib >= 1.1',"SQLAlchemy >= 0.5"],
  zip_safe=False,
  )

if sys.platform == "darwin":
  data.update(
    options={'py2app': {'argv_emulation': True}},
    app=['dsgui.py'],
    setup_requires=['py2app'],
    install_requires=["SQLAlchemy >= 0.5"],
    )

set = setup(**data)
